#include "../htmlindex.h"

void tail()
{

    cout << "\n"
"</tr>\n"
"</table>\n"
"</body></html>\n";
}
